##  Adding Labels to a Template
Use labels to control which fact sheet fields are displayed in diagrams created with this template. Labels highlight specific information, for example, business criticality, hosting description, or external IDs, directly on the diagram.
  1. In the template editor toolbar, open the Labels drop-down menu.![The labels drop-down menu open in a diagram template editor, showing label options for fields.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4c0d04c5c10a428e88697709e6a6f4bc_LowRes.png)
  2. To display the relation name, select Name in the Relation menu.
  3. From the list of available fact sheets, choose a fact sheet type and the field you want to show as the label.
For example, you can choose Application > Functional Fit Description.
  4. Optional: Repeat step 3 for any other fact sheet types you want to configure.
  5. Optional: Choose Save if you want to store the label configuration immediately.
The selected fields are shown as labels on the corresponding shapes whenever users generate diagrams from this template. Labels only affect what is displayed on the diagram.
